%define anolis_release 3

# Enable ASAN + UBSAN
%bcond_with sanitizers
# Embedded unit tests
%bcond_with bin_unit_tests
%bcond_with zchunk

%global libsolv_version 0.7.21
%global libmodulemd_version 2.13.0
%global librepo_version 1.13.1

Name:          rpm-ostree
Version:       2023.2
Release:       %{anolis_release}%{?dist}
License:       LGPLv2+
Summary:       Hybrid image/package system
URL:           https://github.com/coreos/rpm-ostree
Source0:       https://github.com/coreos/rpm-ostree/releases/download/v%{version}/rpm-ostree-%{version}.tar.xz
Source1:       autofiles.py

Patch01:       0001-add-loongarch-support-for-linux-raw-sys.patch
Patch02:       0002-add-loongarch-support-for-nix.patch
Patch03:       0003-add-loongarch-support-for-nix-0.23.1.patch
ExclusiveArch: %{rust_arches}

BuildRequires: make cargo rust python3 jq gcc-c++ gcc
BuildRequires: autoconf automake libtool cmake
# For docs
BuildRequires: chrpath gtk-doc pkgconfig(gobject-introspection-1.0)
BuildRequires: pkgconfig(ostree-1) >= 2021.5 pkgconfig(polkit-gobject-1) pkgconfig(json-glib-1.0)
BuildRequires: pkgconfig(rpm) >= 4.14.0 pkgconfig(libarchive) pkgconfig(libsystemd)
BuildRequires: pkgconfig(libcurl) pkgconfig(expat) pkgconfig(check) pkgconfig(libsolv)
BuildRequires: pkgconfig(libcap) pkgconfig(libattr) pkgconfig(librepo) >= %{librepo_version}


#########################################################################
#                         libdnf build deps                             #
#                                                                       #
# Copy/pasted from libdnf/libdnf.spec. Removed the irrelevant bits like #
# valgrind, rhsm, swig, python, and sanitizer stuff.                    #
#########################################################################

BuildRequires:  libsolv-devel >= %{libsolv_version} pkgconfig(gio-unix-2.0) >= 2.46.0
BuildRequires:  pkgconfig(check) pkgconfig(gtk-doc) pkgconfig(rpm)
%if %{with zchunk}
BuildRequires:  pkgconfig(zck) >= 0.9.11
%endif
BuildRequires:  pkgconfig(sqlite3) pkgconfig(json-c) pkgconfig(cppunit)
BuildRequires:  gettext pkgconfig(gpgme)
BuildRequires:  pkgconfig(modulemd-2.0) >= %{libmodulemd_version} pkgconfig(smartcols)

Requires:       libmodulemd >= %{libmodulemd_version} libsolv >= %{libsolv_version}
Requires:       librepo >= %{librepo_version} ostree bubblewrap fuse skopeo

#########################################################################
#                     end of libdnf build deps                          #
#########################################################################

Requires: %{name}-libs = %{version}-%{release}

%description
rpm-ostree is a hybrid image/package system. It combines libostree as a base 
image format, and accepts RPM on both the client and server side, sharing code 
with the dnf project; specifically libdnf. and thus bringing many of the 
benefits of both together.

%package libs
Summary: Shared library for rpm-ostree

%description libs
The %{name}-libs package includes the shared library for %{name}.

%package devel
Summary: Development headers for %{name}
Requires: %{name}-libs = %{version}-%{release}

%description devel
The %{name}-devel package includes the header files for %{name}-libs.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1 -n %{name}-%{version}

%build
env NOCONFIGURE=1 ./autogen.sh
%if 0%{?build_rustflags:1}
export RUSTFLAGS="%{build_rustflags}"
%endif
%configure --disable-silent-rules --enable-gtk-doc %{?rpmdb_default} %{?with_sanitizers:--enable-sanitizers}  %{?with_bin_unit_tests:--enable-bin-unit-tests}

%make_build

%install
%make_install INSTALL="install -p -c"

python3 %{SOURCE1} > files \
  '%{_bindir}/*' \
  '%{_libdir}/%{name}' \
  '%{_mandir}/man*/*' \
  '%{_datadir}/dbus-1/system.d/*' \
  '%{_sysconfdir}/rpm-ostreed.conf' \
  '%{_prefix}/lib/systemd/system/*' \
  '%{_libexecdir}/rpm-ostree*' \
  '%{_libexecdir}/libostree/ext/*' \
  '%{_datadir}/polkit-1/actions/*.policy' \
  '%{_datadir}/dbus-1/system-services/*' \
  '%{_datadir}/bash-completion/completions/*'

python3 %{SOURCE1} > files.lib \
  '%{_libdir}/*.so.*' \
  '%{_libdir}/girepository-1.0/*.typelib'

python3 %{SOURCE1} > files.devel \
  '%{_libdir}/lib*.so' \
  '%{_includedir}/*' \
  '%{_datadir}/dbus-1/interfaces/org.projectatomic.rpmostree1.xml' \
  '%{_libdir}/pkgconfig/*' \
  '%{_datadir}/gtk-doc/html/*' \
  '%{_datadir}/gir-1.0/*-1.0.gir'

%generate_compatibility_deps

%files -f files
%license LICENSE COPYING.GPL COPYING.LGPL
%{abidir}/rpm-ostree-option.list

%files libs -f files.lib
%dir %{abidir}
%{abidir}/librpmostree-1.dump

%files devel -f files.devel

%files doc
%doc README.md

%changelog
* Thu Oct 19 2023 Jingyun Hua <huajingyun@loongson.cn> - 2023.2-3
- Add loongarch support

* Thu Apr 13 2023 yuanhui <yuanhui@linux.alibaba.com> - 2023.2-2
- Optimize the spec file

* Tue Apr 04 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 2023.2-1
- update version to 2023.2

* Wed Mar 09 2022 Yuanhong Peng <yummypeng@linux.alibaba.com> - 2022.2-1
- Init from upstream v2022.2
